@@ -7,12 +7,12 @@
 ************************************************************************
 **
 **   Copyright (c):  2002      by André Somers
-**                   2008-2010 by Axel Pauli
+**                   2008-2011 by Axel Pauli
 **
 **   This file is distributed under the terms of the General Public
 **   License. See the file COPYING for more information.
 **
-**   $Id: calculator.h 4685 2011-09-21 16:52:31Z axel $
+**   $Id: calculator.h 4744 2011-12-24 19:46:17Z axel $
 **
 ***********************************************************************/
 
@@ -53,7 +53,7 @@ class WindAnalyser;
  *
  * This class represents a single sample of flight data obtained.
  *
- * \date 2002-2010
+ * \date 2002-2011
  */
 class FlightSample
 {
@@ -128,12 +128,12 @@ public:
   /**
    * Different possible flight modes
    */
-  enum flightmode{unknown=0, standstill, cruising, circlingL, circlingR, wave};
+  enum FlightMode {unknown=0, standstill, cruising, circlingL, circlingR};
 
   /**
    * Different sources for position data
    */
-  enum positionFrom{GPS=0, MAN};
+  enum positionFrom {GPS=0, MAN};
 
 public:
   /**
@@ -307,7 +307,7 @@ public:
   /**
    * Returns the current flight mode
    */
-  flightmode currentFlightMode()
+  FlightMode currentFlightMode()
     {
       return lastFlightMode;
     };
@@ -398,17 +398,9 @@ public:
     };
 
   /**
-   * @returns true if we are faster in move as 5km/h.
+   * @returns true if we are faster in move as or equal 35km/h.
    */
-  bool moving()
-  {
-    if( lastSpeed.getKph() > 5 )
-      {
-        return true;
-      }
-
-    return false;
-  };
+  bool moving();
 
 public slots:
 
@@ -519,10 +511,6 @@ public slots:
    * Called if the status of the GPS changes.
    */
   void slot_GpsStatus(GpsNmea::GpsStatus);
-  /**
-   * Connected to the signal flightModeChanged and used to re-emit with marker value
-   */
-  void slot_flightModeChanged(Calculator::flightmode);
   /**
    * Called to switch on/off LD calculation
    */
@@ -653,9 +641,9 @@ signals: // Signals
   void newGlider(const QString&);
 
   /**
-   * Sent if the flight mode changes
+   * Sent if the flight mode has changed.
    */
-  void flightModeChanged(Calculator::flightmode);
+  void flightModeChanged(Calculator::FlightMode);
 
   /**
    * Sent if a new sample has been added to the sample list
@@ -717,6 +705,10 @@ private: // Private methods
    */
   void determineFlightStatus();
 
+  /**
+   * Distributes a flight mode change.
+   */
+  void flightModeChanded(Calculator::FlightMode);
 
 private: // Private attributes
   /** Contains the last flight sample */
@@ -782,7 +774,7 @@ private: // Private attributes
   /** contains the current state of vario calculation */
   bool _calculateVario;
   /** Contains the last known flight mode */
-  flightmode lastFlightMode;
+  FlightMode lastFlightMode;
   /** Last marker value used */
   int _marker;
   /** contains the current state of wind calculation */
