@@ -12,7 +12,7 @@
  **   This file is distributed under the terms of the General Public
  **   License. See the file COPYING for more information.
  **
- **   $Id: generalconfig.cpp 4619 2011-05-04 19:32:17Z axel $
+ **   $Id: generalconfig.cpp 4726 2011-12-20 15:05:02Z axel $
  **
  ***********************************************************************/
 
@@ -244,11 +244,16 @@ void GeneralConfig::load()
 
   beginGroup("Task");
 #ifndef MAEMO
-  _taskCourseLineWidth = value( "CourseLineWidth", 5 ).toInt();
+  _targetLineWidth = value( "TargetLineWidth", 5 ).toInt();
 #else
-  _taskCourseLineWidth = value( "CourseLineWidth", 7 ).toInt();
+  _targetLineWidth = value( "TargetLineWidth", 7 ).toInt();
 #endif
-  _taskCourseLineColor = QColor( value("CourseLineColor", QColor(Qt::darkMagenta).name()).toString() );
+  _targetLineColor = QColor( value("TargetLineColor", QColor(Qt::darkMagenta).name()).toString() );
+  _targetLineDrawState = value( "TargetLineDrawing", true ).toBool();
+
+  _trackLineWidth = value( "TrackLineWidth", 2 ).toInt();
+  _trackLineColor = QColor( value("TrackLineColor", QColor(Qt::gray).name()).toString() );
+  _trackLineDrawState = value( "TrackLineDrawing", true ).toBool();
   endGroup();
 
   beginGroup("Map");
@@ -256,11 +261,10 @@ void GeneralConfig::load()
   _mapUnload                      = value( "UnloadUnneededMap", true ).toBool();
   _downloadMissingMaps            = value( "DownloadMissingMaps", false ).toBool();
   _mapInstallRadius               = value( "MapInstallRadius", 500 ).toInt();
-  _mapBearLine                    = value( "BearLine", true ).toBool();
   _mapLoadIsoLines                = value( "LoadIsoLines", true ).toBool();
   _mapShowIsoLineBorders          = value( "ShowIsoLineBorders", false ).toBool();
   _mapLoadRoads                   = value( "LoadRoads", true ).toBool();
-  _mapLoadHighways                = value( "LoadHighways", true ).toBool();
+  _mapLoadMotorways               = value( "LoadMotorways", true ).toBool();
   _mapLoadRailways                = value( "LoadRailways", true ).toBool();
   _mapLoadCities                  = value( "LoadCities", true ).toBool();
   _mapLoadWaterways               = value( "LoadWaterways", true ).toBool();
@@ -271,6 +275,7 @@ void GeneralConfig::load()
   _mapShowOutLandingLabels        = value( "ShowOutLandingLabels", false ).toBool();
   _mapShowWaypointLabels          = value( "ShowWaypointLabels", false ).toBool();
   _mapShowLabelsExtraInfo         = value( "ShowLabelsExtraInfo", false ).toBool();
+  _mapShowRelBearingInfo          = value( "ShowRelBearingInfo", true ).toBool();
 
   _wayPointScaleBorders[Waypoint::Low]    = value( "WpScaleBorderLow", 125 ).toInt();
   _wayPointScaleBorders[Waypoint::Normal] = value( "WpScaleBorderNormal", 250 ).toInt();
@@ -301,6 +306,7 @@ void GeneralConfig::load()
     }
 
   _groundColor = QColor( value("GroundColor", COLOR_LEVEL_GROUND.name()).toString() );
+  _elevationColorOffset = value("ElevationColorOffset", 0).toInt();
 
   endGroup();
 
@@ -391,6 +397,7 @@ void GeneralConfig::load()
   _gpsSoftStart       = value( "SoftStart", false ).toBool();
   _gpsHardStart       = value( "HardStart", false ).toBool();
   _gpsSyncSystemClock = value( "SyncSystemClock", false ).toBool();
+  _gpsNmeaLogState    = value( "NmeaLogState", false ).toBool();
   _gpsIpcPort         = value( "IpcPort", 0 ).toInt();
   _gpsStartClient     = value( "StartClient", true ).toBool();
   _gpsLastFixLat      = value( "LastFixLat", 0 ).toInt();
@@ -593,8 +600,12 @@ void GeneralConfig::save()
   endGroup();
 
   beginGroup("Task");
-  setValue( "CourseLineWidth", _taskCourseLineWidth );
-  setValue( "CourseLineColor", _taskCourseLineColor.name() );
+  setValue( "TargetLineWidth", _targetLineWidth );
+  setValue( "TargetLineColor", _targetLineColor.name() );
+  setValue( "TargetLineDrawing", _targetLineDrawState );
+  setValue( "TrackLineWidth", _trackLineWidth );
+  setValue( "TrackLineColor", _trackLineColor.name() );
+  setValue( "TrackLineDrawing", _trackLineDrawState );
   endGroup();
 
   beginGroup("Map");
@@ -602,13 +613,14 @@ void GeneralConfig::save()
   setValue( "UnloadUnneededMap", _mapUnload );
   setValue( "DownloadMissingMaps", _downloadMissingMaps );
   setValue( "MapInstallRadius", _mapInstallRadius );
-  setValue( "BearLine", _mapBearLine );
   setValue( "LoadIsoLines", _mapLoadIsoLines );
   setValue( "ShowIsoLineBorders", _mapShowIsoLineBorders );
   setValue( "ShowWaypointLabels", _mapShowWaypointLabels );
   setValue( "ShowLabelsExtraInfo", _mapShowLabelsExtraInfo );
+  setValue( "ShowRelBearingInfo", _mapShowRelBearingInfo );
+
   setValue( "LoadRoads", _mapLoadRoads );
-  setValue( "LoadHighways", _mapLoadHighways );
+  setValue( "LoadMotorways", _mapLoadMotorways );
   setValue( "LoadRailways", _mapLoadRailways );
   setValue( "LoadCities", _mapLoadCities   );
   setValue( "LoadWaterways", _mapLoadWaterways );
@@ -644,6 +656,7 @@ void GeneralConfig::save()
     }
 
   setValue("GroundColor", _groundColor.name());
+  setValue("ElevationColorOffset", _elevationColorOffset);
 
   endGroup();
 
@@ -723,6 +736,7 @@ void GeneralConfig::save()
   setValue( "HardStart", _gpsHardStart );
   setValue( "SoftStart", _gpsSoftStart );
   setValue( "SyncSystemClock", _gpsSyncSystemClock );
+  setValue( "NmeaLogState", _gpsNmeaLogState );
   setValue( "IpcPort", _gpsIpcPort );
   setValue( "StartClient", _gpsStartClient );
   setValue( "LastFixLat", _gpsLastFixLat );
