@@ -12,7 +12,7 @@
 **   This file is distributed under the terms of the General Public
 **   License. See the file COPYING for more information.
 **
-**   $Id: generalconfig.h 4667 2011-09-09 20:42:26Z axel $
+**   $Id: generalconfig.h 4726 2011-12-20 15:05:02Z axel $
 **
 ***********************************************************************/
 
@@ -29,7 +29,7 @@
  *
  * \date 2004-2011
  *
- * \version $Id: generalconfig.h 4667 2011-09-09 20:42:26Z axel $
+ * \version $Id: generalconfig.h 4726 2011-12-20 15:05:02Z axel $
  */
 
 #ifndef GENERAL_CONFIG_H
@@ -1046,17 +1046,6 @@ class GeneralConfig : protected QSettings
     _mapSwitchScale = newValue;
   };
 
-  /** gets Map BearLine */
-  bool getMapBearLine() const
-  {
-    return _mapBearLine;
-  };
-  /** sets Map BearLine */
-  void setMapBearLine(const bool newValue)
-  {
-    _mapBearLine = newValue;
-  };
-
   /** gets Map LoadIsoLines */
   bool getMapLoadIsoLines() const
   {
@@ -1123,6 +1112,17 @@ class GeneralConfig : protected QSettings
     _mapShowOutLandingLabels = newValue;
   };
 
+  /** gets Map ShowRelBearingInfo */
+  bool getMapShowRelBearingInfo() const
+  {
+    return _mapShowRelBearingInfo;
+  };
+  /** sets Map ShowRelBearingInfo */
+  void setMapShowRelBearingInfo(const bool newValue)
+  {
+    _mapShowRelBearingInfo = newValue;
+  };
+
   /** gets Map ShowLabelsExtraInfo */
   bool getMapShowLabelsExtraInfo() const
   {
@@ -1145,15 +1145,15 @@ class GeneralConfig : protected QSettings
     _mapLoadRoads = newValue;
   };
 
-  /** gets Map LoadHighways */
-  bool getMapLoadHighways() const
+  /** gets Map LoadMotorways */
+  bool getMapLoadMotorways() const
   {
-    return _mapLoadHighways;
+    return _mapLoadMotorways;
   };
-  /** sets Map LoadHighways */
-  void setMapLoadHighways(const bool newValue)
+  /** sets Map LoadMotorways */
+  void setMapLoadMotorways(const bool newValue)
   {
-    _mapLoadHighways = newValue;
+    _mapLoadMotorways = newValue;
   };
 
   /** gets Map LoadRailways */
@@ -1928,6 +1928,28 @@ class GeneralConfig : protected QSettings
     _taskSectorAngle = newValue;
   };
 
+  /** gets the target line draw state */
+  bool getTargetLineDrawState() const
+  {
+    return _targetLineDrawState;
+  };
+  /** sets the target line draw state */
+  void setTargetLineDrawState(const bool newValue)
+  {
+    _targetLineDrawState = newValue;
+  };
+
+  /** gets the track line draw state */
+  bool getTrackLineDrawState() const
+  {
+    return _trackLineDrawState;
+  };
+  /** sets the track line draw state */
+  void setTrackLineDrawState(const bool newValue)
+  {
+    _trackLineDrawState = newValue;
+  };
+
   /** Gets the GPS default device depending on the hardware type */
   QString getGpsDefaultDevice();
 
@@ -1949,27 +1971,64 @@ class GeneralConfig : protected QSettings
     return _groundColor;
   };
 
-  /** Sets the task course line color */
-  void setTaskCourseLineColor( const QColor& newValue )
+  /** Gets the elevation color offset index. */
+  int getElevationColorOffset()
   {
-    _taskCourseLineColor = newValue;
+    return _elevationColorOffset;
   };
 
-  /** Gets the task course line color */
-  QColor& getTaskCourseLineColor()
+  /** Sets the elevation color offset index. */
+  void setElevationColorOffset( const int newValue )
   {
-    return _taskCourseLineColor;
+    _elevationColorOffset = newValue;
   };
 
-  /** gets task course line width */
-  int getTaskCourseLineWidth() const
+  /** Sets the target line color */
+  void setTargetLineColor( const QColor& newValue )
   {
-    return _taskCourseLineWidth;
+    _targetLineColor = newValue;
   };
-  /** sets task course line width */
-  void setTaskCourseLineWidth(const int newValue)
+
+  /** Gets the target line color */
+  QColor& getTargetLineColor()
   {
-    _taskCourseLineWidth = newValue;
+    return _targetLineColor;
+  };
+
+  /** gets target line width */
+  int getTargetLineWidth() const
+  {
+    return _targetLineWidth;
+  };
+
+  /** sets target line width */
+  void setTargetLineWidth(const int newValue)
+  {
+    _targetLineWidth = newValue;
+  };
+
+  /** Sets the track line color */
+  void setTrackLineColor( const QColor& newValue )
+  {
+    _trackLineColor = newValue;
+  };
+
+  /** Gets the track line color */
+  QColor& getTrackLineColor()
+  {
+    return _trackLineColor;
+  };
+
+  /** gets track line width */
+  int getTrackLineWidth() const
+  {
+    return _trackLineWidth;
+  };
+
+  /** sets track line width */
+  void setTrackLineWidth(const int newValue)
+  {
+    _trackLineWidth = newValue;
   };
 
   /** Gets waypoint scale border. */
@@ -2007,11 +2066,17 @@ class GeneralConfig : protected QSettings
   // Internet proxy
   QString _proxy;
 
-  // Task course line color
-  QColor _taskCourseLineColor;
+  // Task target line color
+  QColor _targetLineColor;
 
-  // Task course line width
-  int _taskCourseLineWidth;
+  // Task target line width
+  int _targetLineWidth;
+
+  // Task track line color
+  QColor _trackLineColor;
+
+  // Task track line width
+  int _trackLineWidth;
 
   // terrain colors
   QColor _terrainColors[SIZEOF_TERRAIN_COLORS];
@@ -2022,6 +2087,10 @@ class GeneralConfig : protected QSettings
   // terrain ground color, used when the iso line drawing is disabled
   QColor _groundColor;
 
+  // Offset value to be added or subtracted to current elevation
+  // color index value.
+  int _elevationColorOffset;
+
   //properties
   //used to store the distances for airspace warnings
   AirspaceWarningDistance _awd;
@@ -2166,9 +2235,6 @@ class GeneralConfig : protected QSettings
   int _listDisplayAFMargin;
   // Reachable points list row height increase (px)
   int _listDisplayRPMargin;
-
-  // Map BearLine
-  bool _mapBearLine;
   // Map LoadIsoLines
   bool _mapLoadIsoLines;
   // Map ShowIsoLineBorders
@@ -2183,10 +2249,12 @@ class GeneralConfig : protected QSettings
   bool _mapShowTaskPointLabels;
   // Map ShowOutLandingLabels
   bool _mapShowOutLandingLabels;
+  // relative bearing info
+  bool _mapShowRelBearingInfo;
   // Map LoadRoads
   bool _mapLoadRoads;
-  // Map LoadHighways
-  bool _mapLoadHighways;
+  // Map LoadMotorways
+  bool _mapLoadMotorways;
   // Map LoadRailways
   bool _mapLoadRailways;
   // Map LoadCities
@@ -2362,6 +2430,11 @@ class GeneralConfig : protected QSettings
   bool _taskDrawShape;
   bool _taskFillShape;
 
+  // Target line draw state
+  bool _targetLineDrawState;
+  // Track line draw state
+  bool _trackLineDrawState;
+
   /** Waypoint drawing scale borders. Addressed by waypoint priority
    *  (Low=0, Normal=1, High=2). It contains the scale borders defined
    *  user.
