@@ -7,12 +7,12 @@
  ************************************************************************
  **
  **   Copyright (c):  2002      by Eggert Ehmke
- **                   2008-2010 by Axel Pauli
+ **                   2008-2011 by Axel Pauli
  **
  **   This file is distributed under the terms of the General Public
  **   License. See the file COPYING for more information.
  **
- **   $Id: glidereditor.cpp 4342 2010-10-17 17:53:01Z axel $
+ **   $Id: glidereditor.cpp 4725 2011-12-20 10:33:08Z axel $
  **
  ***********************************************************************/
 
@@ -29,8 +29,7 @@
 
 extern MapView *_globalMapView;
 
-GilderEditor::GilderEditor(QWidget *parent, Glider *glider ) :
-  QWidget(parent)
+GilderEditor::GilderEditor(QWidget *parent, Glider *glider ) : QWidget(parent)
 {
   setWindowFlags( Qt::Tool );
   setWindowModality( Qt::WindowModal );
@@ -94,6 +93,16 @@ GilderEditor::GilderEditor(QWidget *parent, Glider *glider ) :
   itemsLayout->addWidget(edtGCall, row, 3);
   row++;
 
+  itemsLayout->addWidget(new QLabel(tr("Wing Area:"), this), row, 0);
+  spinWingArea = new QDoubleSpinBox(this);
+  spinWingArea->setRange(0.0, 100.0);
+  spinWingArea->setSingleStep(1.0);
+  spinWingArea->setButtonSymbols(QSpinBox::PlusMinus);
+  QChar tsChar(Qt::Key_twosuperior);
+  spinWingArea->setSuffix( QString(" m") + tsChar );
+  itemsLayout->addWidget(spinWingArea, row, 1);
+  row++;
+
   itemsLayout->setRowMinimumHeight(row++, 10);
 
   QGridLayout* spinboxLayout = new QGridLayout;
@@ -298,7 +307,7 @@ void GilderEditor::load()
       comboType->setEditText(_glider->type());
       edtGReg->setText(_glider->registration());
       edtGCall->setText(_glider->callSign());
-
+      spinWingArea->setValue( _glider->polar()->wingArea() );
       spinWater->setValue(_glider->maxWater());
 
       if (_glider->seats() == Glider::doubleSeater)
@@ -428,21 +437,23 @@ void GilderEditor::save()
 
   // qDebug("_polar->emptyWeight() %f  _polar->grossWeight() %f",
   //         (float)_glider->polar()->emptyWeight(),  (float)_glider->polar()->grossWeight() );
-  Polar polar( _glider->type(), V1, W1, V2, W2, V3, W3, 0.0, 0.0,
-               emptyWeight->value(), emptyWeight->value() + addedLoad->value() );
+  Polar polar( _glider->type(),
+               V1, W1, V2, W2, V3, W3,
+               0.0,
+               spinWingArea->value(),
+               emptyWeight->value(),
+               emptyWeight->value() + addedLoad->value() );
 
   _glider->setPolar( polar );
 
   // emit glider object to GliderListWidget
   if (isNew)
     {
-      emit
-      newGlider(_glider);
+      emit newGlider(_glider);
     }
   else
     {
-      emit
-      editedGlider(_glider);
+      emit editedGlider(_glider);
     }
 
   isNew = false;
@@ -475,18 +486,31 @@ void GilderEditor::readPolarData()
 
   QTextStream stream(&file);
 
+  int lineNo = 0;
+
   if (file.open(QIODevice::ReadOnly))
     {
       while (!stream.atEnd())
         {
           QString line = stream.readLine().trimmed();
-          // ignore comments
-          if (line[0] == '#')
+
+          lineNo++;
+
+          // ignore comments and empty lines
+          if(line[0] == '#' || line[0] == '*' || line.size() == 0 )
             {
               continue;
             }
 
           QStringList list = line.split(",", QString::KeepEmptyParts);
+
+          if( list.size() < 13 )
+            {
+              // Too less elements
+              qWarning() << "File glider.pol: Format error at line" << lineNo;
+              continue;
+            }
+
           QString glidertype = list[0];
 
           // the sink values are positive in this file; we need them negative
@@ -502,30 +526,19 @@ void GilderEditor::readPolarData()
           double wingarea = list[9].toDouble();
           double emptyMass = list[10].toDouble();
 
-          Polar polar = Polar( glidertype, v1, w1, v2, w2, v3, w3,
-                               wingload, wingarea, emptyMass, emptyMass );
+          Polar polar = Polar( glidertype,
+                               v1, w1, v2, w2, v3, w3,
+                               wingload, wingarea,
+                               emptyMass, emptyMass );
 
-          if (list.count() >= 12)
-            {
-              polar.setMaxWater(list[11].toInt());
-            }
-          else
-            {
-              polar.setMaxWater(0);
-            }
-
-          if (list.count() >= 13)
-            {
-              polar.setSeats(list[12].toInt());
-            }
-          else
-            {
-              polar.setSeats(1);
-            }
+          polar.setMaxWater(list[11].toInt());
+          polar.setSeats(list[12].toInt());
 
           _polars.append( polar );
         }
 
+      file.close();
+
       if( _polars.size() )
         {
           // sort polar data list according to their names
@@ -599,8 +612,6 @@ void GilderEditor::readPolarData()
 /** called when a glider type has been selected */
 void GilderEditor::slotActivated(const QString& type)
 {
-  // qDebug ("GilderEditor::slotActivated(%s)", type.toLatin1().data());
-
   if( !_glider )
     {
       _glider = new Glider();
@@ -615,6 +626,7 @@ void GilderEditor::slotActivated(const QString& type)
     {
       _glider->setPolar( *_polar );
 
+      spinWingArea->setValue( _polar->wingArea() );
       spinV1->setValue( _polar->v1().getHorizontalValue() );
       spinW1->setValue( _polar->w1().getVerticalValue() );
       spinV2->setValue( _polar->v2().getHorizontalValue() );
@@ -652,7 +664,8 @@ void GilderEditor::slotButtonShow()
   W3.setVerticalValue(spinW3->value());
 
   Polar polar( comboType->currentText(),
-               V1, W1, V2, W2, V3, W3, 0.0, 0.0,
+               V1, W1, V2, W2, V3, W3, 0.0,
+               spinWingArea->value(),
                emptyWeight->value(),
                emptyWeight->value() + addedLoad->value() );
 
