@@ -3,13 +3,13 @@
                              -------------------
     begin                : Sat Jul 20 2002
     copyright            : (C) 2002      by André Somers
-                               2008-2010 by Axel Pauli
+                               2008-2011 by Axel Pauli
 
     email                : axel@kflog.org
 
     This file is part of Cumulus
 
-    $Id: igclogger.cpp 4504 2010-12-10 21:06:47Z axel $
+    $Id: igclogger.cpp 4741 2011-12-23 14:28:14Z axel $
 
  ***************************************************************************/
 
@@ -44,8 +44,10 @@ IgcLogger* IgcLogger::_theInstance = static_cast<IgcLogger *> (0);
 
 IgcLogger::IgcLogger(QObject* parent) :
   QObject(parent),
+  closeTimer(0),
   _kRecordLogging(false),
-  _backtrack( LimitedList<QStringList> (15) )
+  _backtrack( LimitedList<QStringList>(30) ),
+  _flightMode( Calculator::unknown)
 {
   if ( GeneralConfig::instance()->getLoggerAutostartMode() )
     {
@@ -67,8 +69,11 @@ IgcLogger::IgcLogger(QObject* parent) :
   lastLoggedKRecord = new QTime();
 
   resetTimer = new QTimer( this );
-
   connect( resetTimer, SIGNAL(timeout()), this, SLOT(slotResetLoggingTime()) );
+
+  closeTimer = new QTimer(this);
+  closeTimer->setSingleShot( true );
+  connect( closeTimer, SIGNAL(timeout()), this, SLOT(slotCloseLogFile()) );
 }
 
 IgcLogger::~IgcLogger()
@@ -104,7 +109,6 @@ IgcLogger* IgcLogger::instance()
 void IgcLogger::slotReadConfig()
 {
   // qDebug( "IgcLogger::slotReadConfig()" );
-
   if( _logMode != on )
     {
       // Don't change mode, if logger is switch on
@@ -139,7 +143,6 @@ void IgcLogger::slotResetLoggingTime()
 void IgcLogger::slotMakeFixEntry()
 {
   // qDebug("IgcLogger::slotMakeFixEntry()");
-
   if ( _logMode == off || calculator->samplelist.count() == 0 )
     {
       // make sure logger is not off and and entries are in the sample list
@@ -164,7 +167,10 @@ void IgcLogger::slotMakeFixEntry()
                    QString("%1").arg(GpsNmea::gps->getLastSatInfo().fixAccuracy, 3, 10, QChar('0')) +
                    QString("%1").arg(GpsNmea::gps->getLastSatInfo().satsInUse, 2, 10, QChar('0')) );
 
-  if ( _logMode == standby && calculator->moving() == false )
+  if ( _logMode == standby &&
+       ( calculator->moving() == false ||
+         _flightMode == Calculator::unknown ||
+         _flightMode == Calculator::standstill ) )
     {
       // save B and F record and time in backtrack, if we are not in move
       QString fRecord = "F" +
@@ -191,6 +197,9 @@ void IgcLogger::slotMakeFixEntry()
           // before start with normal logging. Otherwise the first B record is missing.
           _logMode = on;
 
+          // set start date and time of logging
+          startLogging = QDateTime::currentDateTime();
+
           // If log mode was before in standby we have to write out the backtrack entries.
           if( _backtrack.size() > 0 )
             {
@@ -413,6 +422,9 @@ void IgcLogger::CloseFile()
     {
       _logfile.close();
     }
+
+  // reset logger start time
+  startLogging = QDateTime();
 }
 
 /** This function writes the header of the IGC file into the logfile. */
@@ -732,21 +744,50 @@ QString IgcLogger::createFileName(const QString& path)
 {
   int year=QDate::currentDate().year();
   year=year % 10;
-  int month=QDate::currentDate().month();
-  int day=QDate::currentDate().day();
-  QString name=QString::number(year,10) + QString::number(month,13) + QString::number(day,32);
-  name+="X000"; // @AP: one X has to be added for unknown manufacture
+  int month = QDate::currentDate().month();
+  int day = QDate::currentDate().day();
+  QString name = QString::number(year, 10) + QString::number(month, 13) + QString::number(day, 32);
+  name += "X000"; // @AP: one X has to be added for unknown manufacture
 
   int i=1;
-  QString result=name + QString::number(i,36);
+  QString result=name + QString::number(i, 36);
 
-  while (QFile(path + "/" + result.toUpper() + ".IGC").exists())
+  while ( QFile(path + "/" + result.toUpper() + ".IGC").exists() )
     {
       i++;
-      result=name + QString::number(i,36);
+      result = name + QString::number(i, 36);
     }
 
-  flightNumber=i; //store the resulting number so we can use it in the logfile itself
+  flightNumber = i; //store the resulting number so we can use it in the logfile itself
 
   return path + "/" + result.toUpper() + ".IGC";
 }
+
+void IgcLogger::slotFlightModeChanged( Calculator::FlightMode newFlightMode )
+{
+  _flightMode = newFlightMode;
+
+  if( GeneralConfig::instance()->getLoggerAutostartMode() == false )
+    {
+      // Logger auto start mode not active.
+      return;
+    }
+
+  if( newFlightMode == Calculator::standstill || newFlightMode == Calculator::unknown )
+    {
+      // Close logfile after 90s still stand or unknown mode.
+      closeTimer->start(90000);
+    }
+  else
+    {
+      closeTimer->stop();
+    }
+}
+
+void IgcLogger::slotCloseLogFile()
+{
+  if( GeneralConfig::instance()->getLoggerAutostartMode() )
+    {
+      Standby();
+    }
+}
