@@ -3,13 +3,13 @@
                              -------------------
     begin                : Sat Jul 20 2002
     copyright            : (C) 2002      by André Somers
-                               2008-2010 by Axel Pauli
+                               2008-2011 by Axel Pauli
 
     email                : axel@kflog.org
 
     This file is part of Cumulus
 
-    $Id: igclogger.h 4502 2010-12-09 22:32:02Z axel $
+    $Id: igclogger.h 4741 2011-12-23 14:28:14Z axel $
 
  ***************************************************************************/
 
@@ -32,7 +32,9 @@
  * This class provides the IGC logging facilities, using the
  * parsed data from the GPS NMEA object.
  *
- * \date 2002-2010
+ * \date 2002-2011
+ *
+ * \version $Id: igclogger.h 4741 2011-12-23 14:28:14Z axel $
  */
 
 #ifndef IGC_LOGGER_H
@@ -52,14 +54,14 @@
 #define GPS_CHAN UNKNOWN
 #define GPS_MAXALT UNKNOWN
 
+#include <QDateTime>
+#include <QFile>
 #include <QObject>
 #include <QString>
-#include <QFile>
-#include <QTextStream>
-#include <QTimer>
-#include <QTime>
-#include <QDateTime>
 #include <QStringList>
+#include <QTextStream>
+#include <QTime>
+#include <QTimer>
 
 #include "altitude.h"
 #include "calculator.h"
@@ -105,7 +107,7 @@ public:
   void Standby();
 
   /**
-   * @returns true if we are currently logging
+   * @return true if we are currently logging
    */
   bool getIsLogging() const
   {
@@ -113,13 +115,23 @@ public:
   };
 
   /**
-   * @returns true if we are currently standby
+   * @return true if we are currently standby
    */
   bool getIsStandby() const
   {
     return ( _logMode == standby );
   };
 
+  /**
+   * @return Date and time object containing logger start time, if the logger
+   *         works in auto start mode. If the logger is not running or the
+   *         auto start mode is disabled, the returned object is invalid.
+   */
+  QDateTime& loggerStart()
+  {
+    return startLogging;
+  }
+
 public slots:
   /**
    * This slot is used internally by the timer to make a log entry on
@@ -155,6 +167,11 @@ public slots:
    */
   void slotReadConfig();
 
+  /**
+   * This slot is called, if the flight mode has been changed.
+   */
+  void slotFlightModeChanged( Calculator::FlightMode newFlightMode );
+
 private slots:
 
   /**
@@ -162,6 +179,11 @@ private slots:
    */
   void slotResetLoggingTime();
 
+  /**
+   * This slot is called to close the logfile after a certain timeout.
+   */
+  void slotCloseLogFile();
+
 signals: // Signals
   /**
    * This signal is send to indicate that logging has started
@@ -188,52 +210,6 @@ private:
    */
   void writeKRecord( const QTime& timeFix );
 
-  /**
-   * A pointer to the singleton existing instance.
-   */
-  static IgcLogger* _theInstance;
-
-  /** A timer to reset the logger interval to the default value after a modification. */
-  QTimer* resetTimer;
-
-  /** The text stream object to write our data to. */
-  QTextStream _stream;
-
-  /** This is our log file. It is being used via the _stream object. */
-  QFile _logfile;
-
-  /** Contains the current active logging mode. */
-  LogMode _logMode;
-
-  /** B-Record logger time interval in seconds. */
-  int _bRecordInterval;
-
-  /** K-Record logger time interval in seconds. */
-  int _kRecordInterval;
-
-  /** Enable K-Record logging. */
-  bool _kRecordLogging;
-
-  /** Time stamp of the last logged B record */
-  QTime* lastLoggedBRecord;
-
-  /** Time stamp of the last logged F record */
-  QTime* lastLoggedFRecord;
-
-  /** Time stamp of the last logged K record */
-  QTime* lastLoggedKRecord;
-
-  /** List of last would-be log entries.
-    * This list is filled when in standby mode with strings that would be
-    * in the log were logging enabled. When a change in flight mode is detected
-    * and logging is triggered, the list is used to write out some older events
-    * to the log. This way, we can be sure that the complete start sequence is
-    * available in the log. */
-  LimitedList<QStringList> _backtrack;
-
-  /** Holds the flight number for this day */
-  int flightNumber;
-
   /**
    * Creates a log file, if it not yet already exists and writes the header items
    * into it.
@@ -292,8 +268,61 @@ private:
    * standards (IGC GNSS FR Specification, may 2002, Section 2.5)
    */
   QString createFileName(const QString& path);
+
+  /**
+   * A pointer to the singleton existing instance.
+   */
+  static IgcLogger* _theInstance;
+
+  /** A timer to reset the logger interval to the default value after a modification. */
+  QTimer* resetTimer;
+
+  /** A timer for closing the logfile after a certain timeout.*/
+  QTimer* closeTimer;
+
+  /** The text stream object to write our data to. */
+  QTextStream _stream;
+
+  /** This is our log file. It is being used via the _stream object. */
+  QFile _logfile;
+
+  /** Contains the current active logging mode. */
+  LogMode _logMode;
+
+  /** B-Record logger time interval in seconds. */
+  int _bRecordInterval;
+
+  /** K-Record logger time interval in seconds. */
+  int _kRecordInterval;
+
+  /** Enable K-Record logging. */
+  bool _kRecordLogging;
+
+  /** Time stamp of the last logged B record */
+  QTime* lastLoggedBRecord;
+
+  /** Time stamp of the last logged F record */
+  QTime* lastLoggedFRecord;
+
+  /** Time stamp of the last logged K record */
+  QTime* lastLoggedKRecord;
+
+  /** Date and time start of logging. */
+  QDateTime startLogging;
+
+  /** List of last would-be log entries.
+    * This list is filled when in standby mode with strings that would be
+    * in the log were logging enabled. When a change in flight mode is detected
+    * and logging is triggered, the list is used to write out some older events
+    * to the log. This way, we can be sure that the complete start sequence is
+    * available in the log. */
+  LimitedList<QStringList> _backtrack;
+
+  /** Holds the flight number for this day */
+  int flightNumber;
+
+  /** Holds the last known flight mode. */
+  Calculator::FlightMode _flightMode;
 };
 
 #endif
-
-
