@@ -12,12 +12,12 @@
  **   This file is distributed under the terms of the General Public
  **   License. See the file COPYING for more information.
  **
- **   $Id: mapcontents.cpp 4665 2011-08-27 16:13:57Z axel $
+ **   $Id: mapcontents.cpp 4722 2011-12-19 16:20:34Z axel $
  **
  ***********************************************************************/
 
 #include <cmath>
-#include <stdlib.h>
+#include <cstdlib>
 #include <unistd.h>
 
 #include <QtGui>
@@ -33,7 +33,6 @@
 #include "hwinfo.h"
 #include "isohypse.h"
 #include "lineelement.h"
-#include "map.h"
 #include "mapcalc.h"
 #include "mapcontents.h"
 #include "mapmatrix.h"
@@ -149,10 +148,13 @@ MapContents::MapContents(QObject* parent, WaitScreen* waitscreen) :
       format = "xml";
     }
 
-  qDebug() << "MapContents():" << ok << "waypoints read from default"
-           << format << "catalog.";
+  if( ok )
+    {
+      qDebug() << "MapContents():" << wpList.size() << "waypoints read from"
+               << format << "catalog.";
+    }
 
-  currentTask=0;
+  currentTask = 0;
 
   connect( this, SIGNAL(progress(int)), ws, SLOT(slot_Progress(int)) );
 
@@ -169,7 +171,7 @@ MapContents::~MapContents()
       delete currentTask;
     }
 
-  qDeleteAll (airspaceList);
+  qDeleteAll(airspaceList);
 }
 
 // save the current waypoint list
@@ -1061,12 +1063,12 @@ bool MapContents::__readBinaryFile(const int fileSecID,
 
       switch (typeIn)
         {
-        case BaseMapElement::Highway:
+        case BaseMapElement::Motorway:
           READ_POINT_LIST
 
-          if ( !GeneralConfig::instance()->getMapLoadHighways() ) break;
+          if ( !GeneralConfig::instance()->getMapLoadMotorways() ) break;
 
-          highwayList.append( LineElement("", typeIn, all, false, fileSecID) );
+          motorwayList.append( LineElement("", typeIn, all, false, fileSecID) );
           break;
 
         case BaseMapElement::Road:
@@ -1323,6 +1325,7 @@ bool MapContents::__readBinaryFile(const int fileSecID,
           break;
         default:
           qWarning ("MapContents::__readBinaryFile; type not handled in switch: %d", typeIn);
+          break;
         }
 
       // @AP: Performance brake! emit progress calls waitscreen and
@@ -1999,11 +2002,11 @@ void MapContents::unloadMaps(unsigned int distance)
   qDebug("Unload reportList(%d), elapsed=%d", reportList.count(), t.restart());
 #endif
 
-  unloadMapObjects( highwayList );
+  unloadMapObjects( motorwayList );
 
 #ifdef DEBUG_UNLOAD
   sum += t.elapsed();
-  qDebug("Unload highwayList(%d), elapsed=%d", highwayList.count(), t.restart());
+  qDebug("Unload motorwayList(%d), elapsed=%d", motorwayList.count(), t.restart());
 #endif
 
   unloadMapObjects( roadList );
@@ -2159,8 +2162,8 @@ void MapContents::clearList(const int listIndex)
     case LandmarkList:
       landmarkList.clear();
       break;
-    case HighwayList:
-      highwayList.clear();
+    case MotorwayList:
+      motorwayList.clear();
       break;
     case RoadList:
       roadList.clear();
@@ -2208,8 +2211,8 @@ unsigned int MapContents::getListLength( const int listIndex ) const
       return villageList.count();
     case LandmarkList:
       return landmarkList.count();
-    case HighwayList:
-      return highwayList.count();
+    case MotorwayList:
+      return motorwayList.count();
     case RoadList:
       return roadList.count();
     case RailList:
@@ -2269,8 +2272,8 @@ BaseMapElement* MapContents::getElement(int listType, unsigned int index)
       return &villageList[index];
     case LandmarkList:
       return &landmarkList[index];
-    case HighwayList:
-      return &highwayList[index];
+    case MotorwayList:
+      return &motorwayList[index];
     case RoadList:
       return &roadList[index];
     case RailList:
@@ -2349,7 +2352,7 @@ void MapContents::slotReloadMapData()
   obstacleList.clear();
   railList.clear();
   reportList.clear();
-  highwayList.clear();
+  motorwayList.clear();
   roadList.clear();
   topoList.clear();
   villageList.clear();
@@ -2670,8 +2673,10 @@ void MapContents::drawList( QPainter* targetP,
   // qDebug( "List=%s, Length=%d, drawTime=%dms", list, len, t.elapsed() );
 }
 
-void MapContents::drawList(QPainter* targetP, unsigned int listID)
-  {
+void MapContents::drawList( QPainter* targetP,
+                            unsigned int listID,
+                            QList<BaseMapElement *>& drawnElements )
+{
   //const char *list="";
   //uint len = 0;
 
@@ -2753,7 +2758,13 @@ void MapContents::drawList(QPainter* targetP, unsigned int listID)
       //len=cityList.count();
       showProgress2WaitScreen( tr("Drawing cities") );
       for (int i = 0; i < cityList.size(); i++)
-        cityList[i].drawMapElement(targetP);
+        {
+          if( cityList[i].drawMapElement(targetP) )
+            {
+              drawnElements.append( &cityList[i] );
+            }
+        }
+
       break;
 
     case VillageList:
@@ -2772,12 +2783,12 @@ void MapContents::drawList(QPainter* targetP, unsigned int listID)
         landmarkList[i].drawMapElement(targetP);
       break;
 
-    case HighwayList:
-      //list="HighwayList";
-      //len=highwayList.count();
-      showProgress2WaitScreen( tr("Drawing highways") );
-      for (int i = 0; i < highwayList.size(); i++)
-        highwayList[i].drawMapElement(targetP);
+    case MotorwayList:
+      //list="MotorwayList";
+      //len=MotorwayList.count();
+      showProgress2WaitScreen( tr("Drawing motorways") );
+      for (int i = 0; i < motorwayList.size(); i++)
+        motorwayList[i].drawMapElement(targetP);
       break;
 
     case RoadList:
@@ -2878,6 +2889,8 @@ void MapContents::drawIsoList(QPainter* targetP)
       count++; // yes
     }
 
+  int elevationIndexOffest = GeneralConfig::instance()->getElevationColorOffset();
+
   QMap< int, QList<Isohypse> >* isoMaps[2] = { &groundMap, &terrainMap };
 
   for( int i = 0; i < count; i++ )
@@ -2903,9 +2916,9 @@ void MapContents::drawIsoList(QPainter* targetP)
 
           const QList<Isohypse> &isoList = it.value();
 
-          for (int i = 0; i < isoList.size(); i++)
+         for (int j = 0; j < isoList.size(); j++)
             {
-              Isohypse isoLine = isoList.at(i);
+              Isohypse isoLine = isoList.at(j);
 
               if( drawTerrain )
                 {
@@ -2914,6 +2927,27 @@ void MapContents::drawIsoList(QPainter* targetP)
                   // normally with an offset of one.
                   int colorIdx = isoLine.getElevationIndex();
 
+                  // We can move the color index by a user configuration option
+                  // to get a better color schema.
+                  if( elevationIndexOffest != 0 && i == 1 )
+                    {
+                      int newIndex = colorIdx + elevationIndexOffest;
+
+                      if( newIndex >= 0 && newIndex <= SIZEOF_TERRAIN_COLORS )
+                        {
+                          // Move color index to the new position
+                          colorIdx = newIndex;
+                        }
+                      else if( newIndex < 0 )
+                        {
+                          colorIdx = 0;
+                        }
+                      else if( newIndex >=  SIZEOF_TERRAIN_COLORS )
+                        {
+                          colorIdx = SIZEOF_TERRAIN_COLORS - 1;
+                        }
+                    }
+
                   targetP->setBrush( QBrush(conf->getTerrainColor(colorIdx),
                                      Qt::SolidPattern));
                 }
