@@ -12,7 +12,7 @@
  **   This file is distributed under the terms of the General Public
  **   License. See the file COPYING for more information.
  **
- **   $Id: openairparser.cpp 4581 2011-04-01 19:11:40Z axel $
+ **   $Id: openairparser.cpp 4710 2011-11-25 14:32:36Z axel $
  **
  ***********************************************************************/
 
@@ -313,6 +313,10 @@ bool OpenAirParser::parse(const QString& path, QList<Airspace*>& list)
   QTextStream in(&source);
   in.setCodec( "ISO 8859-15" );
 
+  // Set these values to true to get loaded the first airspace.
+  _acRead = true;
+  _anRead = true;
+
   while( ! in.atEnd() )
     {
       QString line = in.readLine();
@@ -457,6 +461,16 @@ void OpenAirParser::parseLine(QString& line)
       // airspace name
       _anRead = true;
       asName = line.mid(3);
+
+      if( asName == "COLORENTRY" )
+        {
+          // This name is used by Strepla for color definitions.
+          // We ignore that and make a resynchronization
+          _isCurrentAirspace = false;
+          _acRead = true;
+          _anRead = true;
+        }
+
       return;
     }
 
@@ -601,7 +615,6 @@ void OpenAirParser::finishAirspace()
       qWarning() << "OpenAirParser: Line" << _lineNumber
                  << "Object" << asName
                  << "contains to less coordinates! Ignoring it.";
-
       return;
     }
 
@@ -629,7 +642,7 @@ void OpenAirParser::finishAirspace()
   _airlist.append(as);
   _objCounter++;
 
-  // qDebug("finalized airspace %s. %d points in airspace", asName.toLatin1().data(), cnt);
+  // qDebug("finalized airspace %s. %d points in airspace", asName.toLatin1().data(), asPA.count());
 
   if ( _doCompile )
     {
@@ -1465,8 +1478,10 @@ bool OpenAirParser::readCompiledFile( QString &path, QList<Airspace*>& list )
 
   inFile.close();
 
-  //qDebug( "OpenAirParser: %d airspace objects read from file %s in %dms",
-  //       counter, basename(path.toLatin1().data()), t.elapsed() );
+  QFileInfo fi( path );
+
+  qDebug( "OpenAirParser: %d airspace objects read from file %s in %dms",
+          counter, fi.fileName().toLatin1().data(), t.elapsed() );
 
   return true;
 }
