@@ -7,37 +7,45 @@
 ************************************************************************
 **
 **   Copyright (c):  2004 by André Somers
-**                   2008-2010 Axel Pauli
+**                   2008-2011 Axel Pauli
 **
 **   This file is distributed under the terms of the General Public
 **   License. See the file COPYING for more information.
 **
-**   $Id: preflightmiscpage.h 3999 2010-04-27 18:52:37Z axel $
+**   $Id: preflightmiscpage.h 4597 2011-04-28 18:55:45Z axel $
 **
 ***********************************************************************/
 
+/**
+ * \class PreFlightMiscPage
+ *
+ * \author André Somers, Axel Pauli
+ *
+ * \brief A widget for pre-flight miscellaneous settings.
+ *
+ * \date 2004-2011
+ *
+ */
+
 #ifndef PREFLIGHT_MISCPAGE_H
 #define PREFLIGHT_MISCPAGE_H
 
 #include <QWidget>
 #include <QCheckBox>
+#include <QComboBox>
 #include <QSpinBox>
 
 #include "altitude.h"
 
-/**
- * @short Miscelanious pre-flight settings
- * @author André Somers, Axel Pauli
- */
 class PreFlightMiscPage : public QWidget
 {
-    Q_OBJECT
+  Q_OBJECT
 
-  private:
+ private:
 
   Q_DISABLE_COPY ( PreFlightMiscPage )
 
-public:
+ public:
 
     PreFlightMiscPage(QWidget *parent=0);
 
@@ -47,13 +55,14 @@ public:
 
     void save();
 
-private:
+ private:
 
     QCheckBox* chkLogAutoStart;
-    QSpinBox* edtMinimalArrival;
-    QSpinBox* edtQNH;
-    QSpinBox* bRecordInterval; // B-Record logging interval in seconds
-    QSpinBox* kRecordInterval; // K-Record logging interval in seconds
+    QSpinBox*  edtMinimalArrival;
+    QComboBox* edtArrivalAltitude;
+    QSpinBox*  edtQNH;
+    QSpinBox*  bRecordInterval; // B-Record logging interval in seconds
+    QSpinBox*  kRecordInterval; // K-Record logging interval in seconds
 
     /** saves altitude unit set during construction of object */
     Altitude::altitudeUnit altUnit;
