@@ -7,12 +7,12 @@
 ************************************************************************
 **
 **   Copyright (c):  2002      by André Somers
-**                   2009-2010 by Axel Pauli
+**                   2009-2011 by Axel Pauli
 **
 **   This file is distributed under the terms of the General Public
 **   License. See the file COPYING for more information.
 **
-**   $Id: settingspagemapobjects.h 4568 2011-03-27 18:43:19Z axel $
+**   $Id: settingspagemapobjects.h 4726 2011-12-20 15:05:02Z axel $
 **
 *************************************************************************/
 
@@ -23,7 +23,9 @@
  *
  * \brief Configuration settings for map loading and drawing..
  *
- * \date 2002-2010
+ * \date 2002-2011
+ *
+ * \version $Id: settingspagemapobjects.h 4726 2011-12-20 15:05:02Z axel $
  *
  */
 
@@ -104,17 +106,17 @@ private:
   QTableWidgetItem *liIsolines;
   QTableWidgetItem *liIsolineBorders;
   QTableWidgetItem *liRoads;
-  QTableWidgetItem *liHighways;
+  QTableWidgetItem *liMotorways;
   QTableWidgetItem *liRailways;
   QTableWidgetItem *liCities;
   QTableWidgetItem *liWaterways;
   QTableWidgetItem *liForests;
-  QTableWidgetItem *liTargetLine;
   QTableWidgetItem *liWpLabels;
   QTableWidgetItem *liAfLabels;
   QTableWidgetItem *liTpLabels;
   QTableWidgetItem *liOlLabels;
   QTableWidgetItem *liLabelsInfo;
+  QTableWidgetItem *liRelBearingInfo;
 
   // Spin boxes with scale limits according to their priority.
   QSpinBox *wpLowScaleLimitSpinBox;
@@ -125,7 +127,6 @@ private:
    * Fills the list with load options
    */
   void fillLoadOptionList();
-
 };
 
 #endif
